@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 1999, 2000 Bruno Pires Marinho
+ *  Copyright (C) 1999-2001 Bruno Pires Marinho
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -31,8 +31,8 @@ typedef struct
     GtkWidget *dlg;              /* GNOME dialog */
     GtkWidget *url_list;         /* GtkCList */
     GtkWidget *download_dir;     /* Entry */
-    GtkWidget *disable_proxy;    /* Toggle button */
-    GtkWidget *disable_auto_dl;  /* Check button */
+    GtkWidget *use_proxy;        /* Toggle button */
+    GtkWidget *use_auto_dl;      /* Check button */
 } NewDlData;
 
 #define ASC2HEXD(x) (((x) >= '0' && (x) <= '9') ? \
@@ -45,41 +45,58 @@ ok_add_files (GtkWidget *widget, NewDlData *new_dl_data)
 {
     gchar *url, *dir, *error_msg, empty[] = "";
     gint length, pos;
-    gboolean disable_proxy, disable_auto_dl;
+    GTMAppletError result;
+    gboolean use_proxy, use_auto_dl;
 
     /* Get download directory data */
-    if (!gtm_applet_prop.disable_dl_dir)
+    if (gtm_applet_prop.use_dl_dir)
         dir = gtk_entry_get_text (GTK_ENTRY (new_dl_data->download_dir));
     else
         dir = empty;
 
-    /* Get the disable proxy option data */
-    disable_proxy =
+    /* Get the use proxy option data */
+    use_proxy =
         gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (
-            new_dl_data->disable_proxy));
+            new_dl_data->use_proxy));
 
-    /* Get the disable auto download option data */
-    disable_auto_dl = 
+    /* Get the use auto download option data */
+    use_auto_dl = 
         gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (
-	    new_dl_data->disable_auto_dl));
+	    new_dl_data->use_auto_dl));
 
     /* Add the URL from the url list to the file list */
     pos = 0;
     error_msg = g_strconcat (_ ("URL:\n"), NULL);
     while ((url = (gchar *)
             gtk_clist_get_row_data (GTK_CLIST (new_dl_data->url_list),
-                                    pos++)) != NULL)
+                                    pos++)) != NULL) {
         /* Add the new download file to the file list (if not a duplicate) */
-        if (gtm_add_url (url, dir, disable_proxy, disable_auto_dl) == FALSE)
+        result = gtm_add_url (url, dir, use_proxy, use_auto_dl);
+        if (result == GTM_ADDURL_GTM_ERROR) {
+            /* GTM couldn't be started */
+            g_free (error_msg);
+            error_msg = g_strconcat (_ ("Couldn't start GTM"), NULL);
+            break;
+        } else if (result == GTM_ADDURL_CORBA_ERROR) {
+            /* CORBA error */
+            g_free (error_msg);
+            error_msg = g_strconcat (_ ("CORBA error"), NULL);
+            break;
+        } else if (result == GTM_ADDURL_REPEAT_ERROR) {
             /* URL on the file list */
             error_msg = g_strconcat (error_msg, url, "\n", NULL);
+        }
+    }
     
     /* If there where errors give them to the user */
     if (strcmp (error_msg, _("URL:\n")) != 0) {
         GtkWidget *error;
             
-        error_msg = g_strconcat (error_msg, _ ("already in the list"),
-                                 NULL);
+        /* If url == NULL GTM was started and at least one had an error.
+         * Otherwise the error message is already totally set. */
+        if (url == NULL)
+            error_msg = g_strconcat (error_msg, _ ("already in the list"),
+                                     NULL);
         error = gnome_message_box_new (error_msg, GNOME_MESSAGE_BOX_ERROR,
                                        GNOME_STOCK_BUTTON_OK, NULL);
         gnome_dialog_run_and_close (GNOME_DIALOG (error));
@@ -213,6 +230,7 @@ void
 dialog_add (gchar *uri_list)
 {
     GtkWidget *label, *file_entry, *hbox1, *sw;
+    gint result;
     NewDlData *new_dl_data;
 
     if (gtm_applet_prop.confirm_dnd_url) {
@@ -238,7 +256,7 @@ dialog_add (gchar *uri_list)
         gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (new_dl_data->dlg)->vbox), 
                             sw, TRUE, TRUE, 0);
 
-        if (!gtm_applet_prop.disable_dl_dir) {
+        if (gtm_applet_prop.use_dl_dir) {
             label = gtk_label_new (_ ("Download dir:"));
             gtk_box_pack_start (GTK_BOX (
                 GNOME_DIALOG (new_dl_data->dlg)->vbox),
@@ -256,16 +274,20 @@ dialog_add (gchar *uri_list)
         }
 
         hbox1 = gtk_hbox_new (FALSE, FALSE);
-        new_dl_data->disable_proxy = 
-            gtk_check_button_new_with_label (_ ("Disable proxy"));
-        gtk_box_pack_start (GTK_BOX (hbox1), new_dl_data->disable_proxy, 
+        new_dl_data->use_proxy = 
+            gtk_check_button_new_with_label (_ ("Use proxy"));
+        gtk_box_pack_start (GTK_BOX (hbox1), new_dl_data->use_proxy, 
                             FALSE, FALSE, 0);
-        new_dl_data->disable_auto_dl =
-            gtk_check_button_new_with_label (_ ("Disable auto download"));
-        gtk_box_pack_start (GTK_BOX (hbox1), new_dl_data->disable_auto_dl,
+        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (
+            new_dl_data->use_proxy), TRUE);
+        new_dl_data->use_auto_dl =
+            gtk_check_button_new_with_label (_ ("Use auto download"));
+        gtk_box_pack_start (GTK_BOX (hbox1), new_dl_data->use_auto_dl,
                             FALSE, FALSE, 0);
         gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (new_dl_data->dlg)->vbox),
                             hbox1, FALSE, FALSE, 0);
+        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (
+            new_dl_data->use_auto_dl), TRUE);
 
         /* Configure the dialog box */
         gnome_dialog_set_close (GNOME_DIALOG (new_dl_data->dlg), FALSE);
@@ -289,28 +311,44 @@ dialog_add (gchar *uri_list)
         /* Build a valid list of URL */
         urls = url_list_build (uri_list);
         error_msg = g_strconcat (_ ("URL:\n"), NULL);
-        for (p_url = urls; p_url; p_url = g_list_next (p_url))
+        for (p_url = urls; p_url; p_url = g_list_next (p_url)) {
             /* Add the new download file to the file list
              * (if not a duplicate) */
-            if (!gtm_applet_prop.disable_dl_dir) {
-                if (gtm_add_url (p_url->data, gtm_applet_prop.def_download_dir,
-                                 FALSE, FALSE) == FALSE)
-                    /* URL on the file list */
-                    error_msg = g_strconcat (error_msg,
-                                             p_url->data, "\n", NULL);
+            if (gtm_applet_prop.use_dl_dir) {
+                result =
+                    gtm_add_url (p_url->data, gtm_applet_prop.def_download_dir,
+                                 FALSE, FALSE);
             } else {
-                if (gtm_add_url (p_url->data, empty, FALSE, FALSE) == FALSE)
-                    /* URL on the file list */
-                    error_msg = g_strconcat (error_msg,
-                                             p_url->data, "\n", NULL);
+                result =
+                    gtm_add_url (p_url->data, empty,
+                                 FALSE, FALSE);
             }
+            if (result == GTM_ADDURL_GTM_ERROR) {
+                /* GTM couldn't be started */
+                g_free (error_msg);
+                error_msg = g_strconcat (_ ("Couldn't start GTM"), NULL);
+                break;
+            } else if (result == GTM_ADDURL_CORBA_ERROR) {
+                /* CORBA error */
+                g_free (error_msg);
+                error_msg = g_strconcat (_ ("CORBA error"), NULL);
+                break;
+            } else if (result == GTM_ADDURL_REPEAT_ERROR) {
+                /* URL on the file list */
+                error_msg = g_strconcat (error_msg, p_url->data, "\n", NULL);
+            }
+        }
 
         /* If there where errors give them to the user */
         if (strcmp (error_msg, _("URL:\n")) != 0) {
             GtkWidget *error;
 
-            error_msg = g_strconcat (error_msg, _ ("already in the list"),
-                                     NULL);
+            /* If p_url == NULL GTM was started and at least one had an error.
+             * Otherwise GTM couldn't be started and the error message is
+             * already set. */
+            if (p_url == NULL)
+                error_msg = g_strconcat (error_msg, _ ("already in the list"),
+                                         NULL);
             error = gnome_message_box_new (error_msg, GNOME_MESSAGE_BOX_ERROR,
                                            GNOME_STOCK_BUTTON_OK, NULL);
             gnome_dialog_run_and_close (GNOME_DIALOG (error));
