@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 1999, 2000 Bruno Pires Marinho
+ *  Copyright (C) 1999-2001 Bruno Pires Marinho
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -31,8 +31,8 @@ typedef struct
     GtkWidget *dlg;              /* GNOME dialog */
     GtkWidget *url;              /* Entry */
     GtkWidget *download_dir;     /* Entry */
-    GtkWidget *disable_proxy;    /* Toggle button */
-    GtkWidget *disable_auto_dl;  /* Check button */
+    GtkWidget *use_proxy;        /* Toggle button */
+    GtkWidget *use_auto_dl;      /* Check button */
 } NewDlData;
 
 
@@ -42,7 +42,8 @@ ok_new_file (GtkWidget *widget, NewDlData *new_dl_data)
 {
     gchar *url, *dir, *filename, empty[] = "";
     gint length;
-    gboolean disable_proxy, disable_auto_dl;
+    GTMAppletError result;
+    gboolean use_proxy, use_auto_dl;
     GtkWidget *error;
 
     /* Get the URL data and make sure it's right */
@@ -82,28 +83,40 @@ ok_new_file (GtkWidget *widget, NewDlData *new_dl_data)
     }
 
     /* Get download directory data */
-    if (!gtm_applet_prop.disable_dl_dir)
+    if (gtm_applet_prop.use_dl_dir)
         dir = gtk_entry_get_text (GTK_ENTRY (new_dl_data->download_dir));
     else
         dir = empty;
 
-    /* Get the disable proxy option data */
-    disable_proxy =
+    /* Get the use proxy option data */
+    use_proxy =
         gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (
-            new_dl_data->disable_proxy));
+            new_dl_data->use_proxy));
 
-    /* Get the disable auto download option data */
-    disable_auto_dl = 
+    /* Get the use auto download option data */
+    use_auto_dl = 
         gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (
-	    new_dl_data->disable_auto_dl));
+	    new_dl_data->use_auto_dl));
 
     /* Add the new download file to the file list (if not a duplicate) */
-    if (gtm_add_url (url, dir, disable_proxy, disable_auto_dl) == FALSE) {
-        /* URL on the file list */
+    result = gtm_add_url (url, dir, use_proxy, use_auto_dl);
+    if (result != GTM_ADDURL_NO_ERROR) {
         gchar *error_msg;
-        
-        error_msg = g_strconcat (_ ("URL:\n"), url, "\n",
-                                 _ ("already in the list"), NULL);
+
+        if (result == GTM_ADDURL_GTM_ERROR) {
+            /* GTM couldn't be started */
+            error_msg = g_strconcat (_ ("Couldn't start GTM"), NULL);
+        } else if (result == GTM_ADDURL_CORBA_ERROR) {
+            /* CORBA error */
+            error_msg = g_strconcat (_ ("CORBA error"), NULL);
+        } else if (result == GTM_ADDURL_REPEAT_ERROR) {
+            /* URL on the file list */
+            error_msg = g_strconcat (_ ("URL:\n"), url, "\n",
+                                     _ ("already in the list"), NULL);
+        } else {
+            /* Unknown code */
+            error_msg = g_strconcat ("", NULL);
+        }
         error = gnome_message_box_new (error_msg, GNOME_MESSAGE_BOX_ERROR,
                                        GNOME_STOCK_BUTTON_OK, NULL);
         gnome_dialog_run_and_close (GNOME_DIALOG (error));
@@ -112,7 +125,7 @@ ok_new_file (GtkWidget *widget, NewDlData *new_dl_data)
     
     /* If dialog new or add changes default download dir update the def dl 
      * dir */
-    if (!gtm_applet_prop.disable_dl_dir 
+    if (gtm_applet_prop.use_dl_dir 
         && gtm_applet_prop.addnew_changes_def_dl_dir) {
         g_free (gtm_applet_prop.def_download_dir);
         length = strlen (dir);
@@ -128,6 +141,18 @@ ok_new_file (GtkWidget *widget, NewDlData *new_dl_data)
     g_free (new_dl_data);
 }
 
+static void
+dialog_new_drag_data_received (GtkWidget *widget, GdkDragContext *context,
+                               gint x, gint y, 
+                               GtkSelectionData *selection_data,
+                               guint info, guint time,
+                               NewDlData *new_dl_data)
+{
+    g_return_if_fail (widget != NULL);
+    g_return_if_fail (selection_data->data != NULL);
+    gtk_entry_set_text (GTK_ENTRY (new_dl_data->url), selection_data->data);
+}
+
 static void
 cancel_new_file (GtkWidget *widget, NewDlData *new_dl_data)
 {
@@ -144,6 +169,14 @@ dialog_new (void)
     GtkWidget *label, *file_entry, *hbox1;
     NewDlData *new_dl_data;
 
+    static GtkTargetEntry target_table[] = {
+        { "text/uri-list", 0, 0 },
+        { "text/plain", 0, 0 },
+        { "x-url/http", 0, 0 },
+        { "x-url/ftp", 0, 0 },
+        { "_NETSCAPE_URL", 0, 0 }
+    };
+
     new_dl_data = g_new (NewDlData, 1);
 
     /* Create dialog box */
@@ -162,7 +195,7 @@ dialog_new (void)
 			new_dl_data->url, FALSE, FALSE, 0);
     gtk_widget_grab_focus (new_dl_data->url);
 
-    if (!gtm_applet_prop.disable_dl_dir) {
+    if (gtm_applet_prop.use_dl_dir) {
         label = gtk_label_new (_ ("Download dir:"));
         gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (new_dl_data->dlg)->vbox), 
                             label, FALSE, FALSE, 0);
@@ -178,21 +211,32 @@ dialog_new (void)
     }
 
     hbox1 = gtk_hbox_new(FALSE, FALSE);
-    new_dl_data->disable_proxy = 
-	gtk_check_button_new_with_label (_ ("Disable proxy"));
-    gtk_box_pack_start (GTK_BOX (hbox1), new_dl_data->disable_proxy,
+    new_dl_data->use_proxy = 
+	gtk_check_button_new_with_label (_ ("Use proxy"));
+    gtk_box_pack_start (GTK_BOX (hbox1), new_dl_data->use_proxy,
                         FALSE, FALSE, 0);
-    new_dl_data->disable_auto_dl =
-        gtk_check_button_new_with_label (_ ("Disable auto download"));
-    gtk_box_pack_start (GTK_BOX (hbox1), new_dl_data->disable_auto_dl,
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (
+        new_dl_data->use_proxy), TRUE);
+    new_dl_data->use_auto_dl =
+        gtk_check_button_new_with_label (_ ("Use auto download"));
+    gtk_box_pack_start (GTK_BOX (hbox1), new_dl_data->use_auto_dl,
                         FALSE, FALSE, 0);
     gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (new_dl_data->dlg)->vbox),
                         hbox1, FALSE, FALSE, 0);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (
+        new_dl_data->use_auto_dl), TRUE);
 
     /* Configure the dialog box */
     gnome_dialog_set_close (GNOME_DIALOG (new_dl_data->dlg), FALSE);
     gnome_dialog_set_default (GNOME_DIALOG (new_dl_data->dlg), GNOME_OK);
 
+    /* Set drag 'n drop stuff */
+    gtk_drag_dest_set (new_dl_data->url, GTK_DEST_DEFAULT_MOTION 
+		       | GTK_DEST_DEFAULT_DROP,
+                       target_table, 
+		       sizeof (target_table) / sizeof (target_table[0]),
+                       GDK_ACTION_COPY | GDK_ACTION_MOVE);
+
     /* Set the signal handlers */
     gnome_dialog_button_connect (GNOME_DIALOG (new_dl_data->dlg), GNOME_OK,
 				 GTK_SIGNAL_FUNC (ok_new_file),
@@ -203,6 +247,9 @@ dialog_new (void)
     gtk_signal_connect (GTK_OBJECT (new_dl_data->url), "activate",
 			GTK_SIGNAL_FUNC (ok_new_file), 
 			(gpointer) new_dl_data);
+    gtk_signal_connect (GTK_OBJECT (new_dl_data->url), "drag_data_received",
+                        GTK_SIGNAL_FUNC (dialog_new_drag_data_received),
+                        (gpointer) new_dl_data);
 
     /* Show the dialog box and every thing it contains */
     gtk_widget_show_all (new_dl_data->dlg);
