@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 1999, 2000 Bruno Pires Marinho
+ *  Copyright (C) 1999-2001 Bruno Pires Marinho
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@ typedef struct
     GtkWidget *addnew_changes_def_dl_dir;       /* Toggle button */
     GtkWidget *confirm_dnd_url;                 /* Toggle button */
     gint binding_button1_click;
-    GtkWidget *disable_dl_dir;                  /* Toggle button */
+    GtkWidget *use_dl_dir;                      /* Toggle button */
 } PropDialogData;
 
 static PropDialogData *prop_dialog_data = NULL;
@@ -37,10 +37,10 @@ static PropDialogData *prop_dialog_data = NULL;
 static void
 apply_prop_download (PropDialogData *prop)
 {
-    /* Disable download directory */
-    gtm_applet_prop.disable_dl_dir =
+    /* Use download directory */
+    gtm_applet_prop.use_dl_dir =
         gtk_toggle_button_get_active (
-            GTK_TOGGLE_BUTTON (prop->disable_dl_dir));
+            GTK_TOGGLE_BUTTON (prop->use_dl_dir));
 
     /* Default download directory */
     gtm_applet_prop.def_download_dir = 
@@ -103,7 +103,7 @@ apply_prop (GtkWidget *widget, gint page_num, PropDialogData *prop)
     gnome_config_set_int ("binding_button1_click",
                           gtm_applet_prop.binding_button1_click);
     gnome_config_set_bool ("disable_dl_dir",
-                           gtm_applet_prop.disable_dl_dir);
+                           !gtm_applet_prop.use_dl_dir);
     gnome_config_pop_prefix ();
 }
 
@@ -120,10 +120,10 @@ prop_modified_cb (GtkWidget *widget, PropDialogData *prop)
 {
     /* Change the sensitivity of the proxy preferences */
     if (gtk_toggle_button_get_active (
-        GTK_TOGGLE_BUTTON (prop_dialog_data->disable_dl_dir))) {
-        gtk_widget_set_sensitive (prop_dialog_data->def_download_dir, FALSE);
-    } else {
+        GTK_TOGGLE_BUTTON (prop_dialog_data->use_dl_dir))) {
         gtk_widget_set_sensitive (prop_dialog_data->def_download_dir, TRUE);
+    } else {
+        gtk_widget_set_sensitive (prop_dialog_data->def_download_dir, FALSE);
     }
 
     /* Tell to property box that data changed */
@@ -147,10 +147,10 @@ create_download_page (PropDialogData *prop)
     vbox = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
     gtk_container_set_border_width (GTK_CONTAINER (vbox), GNOME_PAD);
     
-    /* Disable download dir */
-    prop->disable_dl_dir = 
-        gtk_check_button_new_with_label (_ ("Disable the download dir"));
-    gtk_box_pack_start (GTK_BOX (vbox), prop->disable_dl_dir, FALSE,
+    /* Use download dir */
+    prop->use_dl_dir = 
+        gtk_check_button_new_with_label (_ ("Use download dir"));
+    gtk_box_pack_start (GTK_BOX (vbox), prop->use_dl_dir, FALSE,
                         FALSE, 0);
 
     /* Default download directory */
@@ -168,16 +168,16 @@ create_download_page (PropDialogData *prop)
 
     /* Set current properties */
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (
-        prop->disable_dl_dir), gtm_applet_prop.disable_dl_dir);
+        prop->use_dl_dir), gtm_applet_prop.use_dl_dir);
     gtk_entry_set_text (GTK_ENTRY (prop->def_download_dir), 
                         gtm_applet_prop.def_download_dir);
-    if (gtm_applet_prop.disable_dl_dir == TRUE) {
+    if (gtm_applet_prop.use_dl_dir == FALSE) {
         gtk_widget_set_sensitive (prop_dialog_data->def_download_dir, FALSE);
     }
 
     /* Connect the signal that acknowledges the change on the widget to 
      * function that turns on the OK and APPLY buttons */
-    gtk_signal_connect (GTK_OBJECT (prop->disable_dl_dir),
+    gtk_signal_connect (GTK_OBJECT (prop->use_dl_dir),
                         "toggled", GTK_SIGNAL_FUNC (prop_modified_cb),
                         (gpointer) prop);
     gtk_signal_connect (GTK_OBJECT (prop->def_download_dir), "changed",
