@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 1999, 2000 Bruno Pires Marinho
+ *  Copyright (C) 1999-2001 Bruno Pires Marinho
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,11 +19,25 @@
 #include <config.h>
 #include <gnome.h>
 #include <applet-widget.h>
+#include <libgnomeui/gnome-window-icon.h>
+#include <gdk/gdkx.h>
+#include <gdk/gdkprivate.h>
+#include <X11/extensions/shape.h>
 #include "Gtm.h"
 #include "dialogs.h"
 #include "gtm_applet.h"
 #include "tray_empty.xpm"
 #include "tray_full.xpm"
+#ifdef HAVE_PANEL_PIXEL_SIZE
+#include "tray_empty_huge.xpm"
+#include "tray_full_huge.xpm"
+#include "tray_empty_large.xpm"
+#include "tray_full_large.xpm"
+#include "tray_empty_small.xpm"
+#include "tray_full_small.xpm"
+#include "tray_empty_tiny.xpm"
+#include "tray_full_tiny.xpm"
+#endif
 
 /* Pixmaps used on the application */
 static GdkPixmap *i_open;
@@ -32,6 +46,13 @@ static GdkPixmap *i_closed;
 static GdkPixmap *i_closed_mask;
 
 static GtkWidget *eventbox;
+static GtkWidget *applet;
+static GtkWidget *pixmap;
+
+#ifdef HAVE_PANEL_PIXEL_SIZE
+static int panel_size;
+#endif
+static PanelOrientType panel_orient;
 
 /* Used to keep current drag state */
 static gboolean have_drag;
@@ -49,24 +70,25 @@ Properties gtm_applet_prop;
 
 
 /* Open gtm */
-void
+gboolean
 gtm_open (void)
 {
-    goad_server_activate_with_repo_id (NULL, "IDL:gtm/download:1.0", 0,
-				       NULL);
+    if (goad_server_activate_with_repo_id (NULL, "IDL:gtm/download:1.0", 0,
+                                           NULL) == NULL)
+        return FALSE;
+    else
+        return TRUE;
 }
 
 
 /* Add a new URL to gtm */
-gboolean
-gtm_add_url (gchar *url, gchar *dir, gboolean disable_proxy,
-             gboolean disable_auto_dl)
+GTMAppletError
+gtm_add_url (gchar *url, gchar *dir, gboolean use_proxy, gboolean use_auto_dl)
 {
     CORBA_Environment ev;
     GTM_Download gtm_download_client;
-    gboolean result;
+    GTMAppletError result;
 
-    result = FALSE;
     gtm_download_client = 
         goad_server_activate_with_repo_id (NULL,
                                            "IDL:gtm/download:1.0", 0,
@@ -74,14 +96,19 @@ gtm_add_url (gchar *url, gchar *dir, gboolean disable_proxy,
 
     if (gtm_download_client != NULL) {
         CORBA_exception_init (&ev);
-        result = GTM_Download_add_url (gtm_download_client, url, dir,
-                                       disable_proxy, disable_auto_dl, &ev);
+        if (GTM_Download_add_url (gtm_download_client, url, dir,
+                                   !use_proxy, !use_auto_dl, &ev))
+            result = GTM_ADDURL_NO_ERROR;
+        else
+            result = GTM_ADDURL_REPEAT_ERROR;
         if (ev._major != CORBA_NO_EXCEPTION) {
             g_print ("Exception thrown: %s\n",
                      CORBA_exception_id (&ev));
             CORBA_exception_free (&ev);
+            result = GTM_ADDURL_CORBA_ERROR;
         }
-    }
+    } else
+        result = GTM_ADDURL_GTM_ERROR;
 
     return result;
 }
@@ -110,8 +137,8 @@ property_load (gchar *path)
             gnome_config_get_bool ("gtm_applet/confirm_dnd_url=FALSE");
         gtm_applet_prop.binding_button1_click =
             gnome_config_get_int ("gtm_applet/binding_button1_click=1");
-        gtm_applet_prop.disable_dl_dir =
-            gnome_config_get_bool ("gtm_applet/disable_dl_dir=FALSE");
+        gtm_applet_prop.use_dl_dir =
+            !gnome_config_get_bool ("gtm_applet/disable_dl_dir=FALSE");
         gnome_config_pop_prefix ();
     } else {
         gnome_config_push_prefix ("gtm_applet/Default/");
@@ -128,8 +155,8 @@ property_load (gchar *path)
             gnome_config_get_bool ("confirm_dnd_url=FALSE");
         gtm_applet_prop.binding_button1_click =
             gnome_config_get_int ("binding_button1_click=1");
-        gtm_applet_prop.disable_dl_dir =
-            gnome_config_get_bool ("disable_dl_dir=FALSE");
+        gtm_applet_prop.use_dl_dir =
+            !gnome_config_get_bool ("disable_dl_dir=FALSE");
         gnome_config_pop_prefix ();
     }
 }
@@ -147,7 +174,7 @@ property_save (gchar *path)
     gnome_config_set_int ("gtm_applet/binding_button1_click",
                           gtm_applet_prop.binding_button1_click);
     gnome_config_set_bool ("gtm_applet/disable_dl_dir",
-                           gtm_applet_prop.disable_dl_dir);
+                           !gtm_applet_prop.use_dl_dir);
     gnome_config_pop_prefix ();
 }
 
@@ -166,7 +193,14 @@ applet_save_session (GtkWidget *widget, char *privcfgpath, char *globcfgpath)
 static void
 cmd_gtm_open (AppletWidget *widget, gpointer data)
 {
-    gtm_open ();
+    GtkWidget *error;
+
+    if (!gtm_open ()) {
+	error = gnome_message_box_new (
+	    _ ("Couldn't start GTM"), GNOME_MESSAGE_BOX_ERROR, 
+	    GNOME_STOCK_BUTTON_OK, NULL);
+	gnome_dialog_run_and_close (GNOME_DIALOG (error));        
+    }
 }
 
 
@@ -193,13 +227,100 @@ cmd_about (AppletWidget *widget, gpointer data)
     dialog_about ();
 }
 
+/* redraw the applet pixmap because either the drag state or size changed */
+static void
+applet_redraw_pixmap ()
+{
+    GdkWindowPrivate *sock_win =
+        (GdkWindowPrivate *) GTK_PLUG(applet)->socket_window;
+    Window root_return;
+    Window parent_return;
+    Window *children_return;
+    unsigned int nchildren_return;
+
+    /* find the evil parent window */
+    XQueryTree (GDK_DISPLAY (), GDK_WINDOW_XWINDOW (sock_win),
+                &root_return, &parent_return, &children_return,
+                &nchildren_return);
+    XFree(children_return);
+
+    if (have_drag) {
+        gtk_pixmap_set (GTK_PIXMAP (pixmap), i_open, i_open_mask);
+        gtk_widget_shape_combine_mask (applet, i_open_mask, 0, 0);
+
+        /* Set the mask for our parent, too */
+        XShapeCombineMask (GDK_DISPLAY (), parent_return,
+                           ShapeBounding, 0, 0,
+                           ((GdkWindowPrivate *)i_open_mask)->xwindow,
+                           ShapeSet);
+    } else {
+        gtk_pixmap_set (GTK_PIXMAP (pixmap), i_closed, i_closed_mask);
+        gtk_widget_shape_combine_mask (applet, i_closed_mask, 0, 0);
+
+        /* Set the mask for our parent, too */
+        XShapeCombineMask (GDK_DISPLAY (), parent_return,
+                           ShapeBounding, 0, 0,
+                           ((GdkWindowPrivate *)i_closed_mask)->xwindow,
+                           ShapeSet);
+    }
+}
+
+/* update the pixmaps for the current panel size */
+static void
+applet_update_pixmaps ()
+{
+    gchar **full_xpm;
+    gchar **empty_xpm;
+
+    if (i_open)
+        gdk_pixmap_unref (i_open);
+    if (i_closed)
+        gdk_pixmap_unref (i_closed);
+
+#ifdef HAVE_PANEL_PIXEL_SIZE
+    switch (panel_size) {
+        case PIXEL_SIZE_HUGE:
+            full_xpm = tray_full_huge_xpm;
+            empty_xpm = tray_empty_huge_xpm;
+            break;
+        case PIXEL_SIZE_LARGE:
+            full_xpm = tray_full_large_xpm;
+            empty_xpm = tray_empty_large_xpm;
+            break;
+        case PIXEL_SIZE_SMALL:
+            full_xpm = tray_full_small_xpm;
+            empty_xpm = tray_empty_small_xpm;
+            break;
+        case PIXEL_SIZE_TINY:
+            full_xpm = tray_full_tiny_xpm;
+            empty_xpm = tray_empty_tiny_xpm;
+            break;
+        case PIXEL_SIZE_STANDARD:
+        default:
+            full_xpm = tray_full_xpm;
+            empty_xpm = tray_empty_xpm;
+    }
+#else
+    full_xpm = tray_full_xpm;
+    empty_xpm = tray_empty_xpm;
+#endif
+    
+    i_open = gdk_pixmap_colormap_create_from_xpm_d (
+        NULL,
+        gtk_widget_get_colormap (applet),
+        &i_open_mask, NULL, full_xpm);
+    i_closed = gdk_pixmap_colormap_create_from_xpm_d (
+        NULL,
+        gtk_widget_get_colormap (applet),
+        &i_closed_mask, NULL, empty_xpm);
+}
 
 /* Drag 'n drop stuff */
 static void  
 drag_leave_cb (GtkWidget *widget, GdkDragContext *context, guint time)
 {
     have_drag = FALSE;
-    gtk_pixmap_set (GTK_PIXMAP (widget), i_closed, i_closed_mask);
+    applet_redraw_pixmap();
 }
 
 static gboolean
@@ -208,7 +329,7 @@ drag_motion_cb (GtkWidget *widget, GdkDragContext *context, gint x, gint y,
 {
     if (!have_drag) {
         have_drag = TRUE;
-        gtk_pixmap_set (GTK_PIXMAP (widget), i_open, i_open_mask);
+        applet_redraw_pixmap();
     }
 
     gdk_drag_status (context, context->suggested_action, time);
@@ -242,7 +363,7 @@ applet_cmd_by_type (GTMAppletCmd cmd)
             break;
 
         case GTM_ACTION_OPEN_GTM:
-            gtm_open ();
+            cmd_gtm_open (NULL, NULL);
             break;
 
         case GTM_ACTION_NONE:
@@ -267,105 +388,73 @@ applet_clicked_cb (GtkWidget *widget, GdkEventButton *event, gpointer data)
     return FALSE;
 }
 
+/* Match the panel's orientation */
 static void
-applet_set_back_color(GdkColor *color)
+applet_change_orient (GtkWidget *w, PanelOrientType o, gpointer data)
 {
-    
-    GtkStyle *ns;
-
-    ns = gtk_style_copy(eventbox->style);
-    gtk_style_ref(ns);
-
-    ns->bg[GTK_STATE_NORMAL] = *color;
-    ns->bg[GTK_STATE_NORMAL].pixel = 1; /* bogus */
-
-    if(ns->bg_pixmap[GTK_STATE_NORMAL]) {
-        gdk_imlib_free_pixmap(ns->bg_pixmap[GTK_STATE_NORMAL]);
-        ns->bg_pixmap[GTK_STATE_NORMAL] = NULL;
-    }
-
-    gtk_widget_set_style(eventbox, ns);
-
-    gtk_style_unref(ns);
-
-    gtk_widget_queue_draw(GTK_WIDGET(eventbox));
+    panel_orient = o;
 }
 
-static void
-applet_set_back_pixmap(gchar *pixmap)
-{
-    GdkImlibImage *im;
-    GdkPixmap *p;
-    GtkStyle *ns;
-
-    if(!pixmap || strcmp(pixmap,"")==0) {
-        ns = gtk_style_copy(eventbox->style);
-        gtk_style_ref(ns);
-
-        p = ns->bg_pixmap[GTK_STATE_NORMAL];
-        if(p)
-            gdk_imlib_free_pixmap (p);
-        ns->bg_pixmap[GTK_STATE_NORMAL] = NULL;
-
-        gtk_widget_set_style(eventbox, ns);
-
-        gtk_style_unref(ns);
-        return;
-    }
-
-    if (!g_file_exists (pixmap))
-        return;
-
-    im = gdk_imlib_load_image (pixmap);
-    if (!im)
-        return;
-
-    gdk_imlib_render (im, im->rgb_width, im->rgb_height);
-
-    p = gdk_imlib_move_image (im);
-
-    ns = gtk_style_copy(eventbox->style);
-    gtk_style_ref(ns);
-
-    if(ns->bg_pixmap[GTK_STATE_NORMAL])
-        gdk_imlib_free_pixmap (ns->bg_pixmap[GTK_STATE_NORMAL]);
-    ns->bg_pixmap[GTK_STATE_NORMAL] = p;
-
-    gtk_widget_set_style(eventbox, ns);
-
-    gtk_style_unref(ns);
-    gdk_imlib_destroy_image (im);
-}
-
-static void
-applet_set_default_back()
-{
-    gtk_widget_set_rc_style (eventbox);
-    gtk_widget_queue_draw (GTK_WIDGET (eventbox));
-}
-
-
 /* Match the panel's background */
 static void
-applet_back_change(GtkWidget *w,
-                   PanelBackType type,
-                   gchar *pxmap,
-                   GdkColor *color,
-                   gpointer data)
+applet_back_change (GtkWidget *w,
+                    PanelBackType type,
+                    gchar *pix,
+                    GdkColor *color,
+                    gpointer data)
 {
-    if (type == PANEL_BACK_PIXMAP)
-        applet_set_back_pixmap (pxmap);
-    else if (type == PANEL_BACK_COLOR)
-        applet_set_back_color (color);
-    else
-        applet_set_default_back ();
+    GtkStyle *ns;
+
+    switch (type) {
+        case PANEL_BACK_NONE:
+            ns = gtk_style_new ();
+            gtk_style_ref (ns);
+            gtk_widget_set_style (applet, ns);
+            gtk_style_unref (ns);
+            break;
+
+        case PANEL_BACK_COLOR:
+            ns = gtk_style_copy (GTK_WIDGET (applet)->style);
+            gtk_style_ref (ns);
+            ns->bg[GTK_STATE_NORMAL] = *color;
+            gtk_widget_set_style (GTK_WIDGET (applet), ns);
+            gtk_style_unref (ns);
+            break;
+
+        case PANEL_BACK_PIXMAP:
+            if (pix != NULL && g_file_exists (pix)) {
+                GdkImlibImage *im = gdk_imlib_load_image (pix);
+                if (im) {
+                    GdkPixmap *pmap;
+
+                    gdk_imlib_render (im, im->rgb_width, im->rgb_height);
+                    pmap = gdk_imlib_copy_image (im);
+                    gdk_imlib_destroy_image (im);
+                    gdk_window_set_back_pixmap (applet->window, pmap,
+                                                FALSE);
+                    gdk_window_clear (applet->window);
+                    gdk_pixmap_unref (pmap);
+                }
+            }
+            break;
+    }
 }
 
+#ifdef HAVE_PANEL_PIXEL_SIZE
+/* Match the panel's size */
+static void
+applet_change_pixel_size (GtkWidget *w, int size, gpointer data)
+{
+    panel_size = size;
+    applet_update_pixmaps();
+    applet_redraw_pixmap();
+}
+#endif
+
 /* Main program */
 int 
 main (int argc, char *argv[])
 {
-    GtkWidget *applet, *pixmap;
     static GtkTargetEntry target_table[] = {
         { "text/uri-list", 0, TARGET_URL },
         { "text/plain", 0, TARGET_URL },
@@ -380,6 +469,7 @@ main (int argc, char *argv[])
    
     /* Initialize the applet */
     applet_widget_init ("gtm_applet", VERSION, argc, argv, NULL, 0, NULL);
+    gnome_window_icon_set_default_from_file (GNOME_ICONDIR "/gtm.png");
     applet = applet_widget_new ("gtm_applet");
     if (!applet)
 	g_error ("Can't create applet!\n");
@@ -388,14 +478,9 @@ main (int argc, char *argv[])
     property_load (APPLET_WIDGET (applet)->privcfgpath);
 
     /* Load pixmaps */
-    i_open = gdk_pixmap_colormap_create_from_xpm_d (
-        NULL,
-        gtk_widget_get_colormap (applet),
-        &i_open_mask, NULL, tray_full_xpm);
-    i_closed = gdk_pixmap_colormap_create_from_xpm_d (
-        NULL,
-        gtk_widget_get_colormap (applet),
-        &i_closed_mask, NULL, tray_empty_xpm);
+    i_open = 0;
+    i_closed = 0;
+    applet_update_pixmaps();
                                                
     /* Create widget eventbox with a pixmap for to new URL */
     eventbox = gtk_event_box_new ();
@@ -424,7 +509,18 @@ main (int argc, char *argv[])
 
     /* Handle panel background change */
     gtk_signal_connect (GTK_OBJECT (applet),"back_change",
-                        GTK_SIGNAL_FUNC(applet_back_change), NULL);
+                        GTK_SIGNAL_FUNC (applet_back_change), NULL);
+
+    /* Handle panel orientation change */
+    gtk_signal_connect (GTK_OBJECT (applet),"change_orient",
+                        GTK_SIGNAL_FUNC (applet_change_orient), NULL);
+
+#ifdef HAVE_PANEL_PIXEL_SIZE
+    /* Set panel resize handler */
+    gtk_signal_connect (GTK_OBJECT (applet), "change_pixel_size",
+                        GTK_SIGNAL_FUNC (applet_change_pixel_size),
+                        NULL);
+#endif
 
     /* Add the eventbox to the applet and show the applet */
     applet_widget_add (APPLET_WIDGET (applet), eventbox);
@@ -463,4 +559,3 @@ main (int argc, char *argv[])
     applet_widget_gtk_main();
     return 0;
 }
-
