@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 1999, 2000 Bruno Pires Marinho
+ *  Copyright (C) 1999-2001 Bruno Pires Marinho
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -26,21 +26,28 @@ typedef enum {
     GTM_ACTION_OPEN_GTM,
 } GTMAppletCmd;
 
+typedef enum {
+    GTM_ADDURL_NO_ERROR,
+    GTM_ADDURL_GTM_ERROR,
+    GTM_ADDURL_REPEAT_ERROR,
+    GTM_ADDURL_CORBA_ERROR
+} GTMAppletError;
+
 typedef struct 
 {
     gchar *def_download_dir;
     gboolean addnew_changes_def_dl_dir;
     gboolean confirm_dnd_url;
     GTMAppletCmd binding_button1_click;
-    gboolean disable_dl_dir;
+    gboolean use_dl_dir;
 } Properties;
 
 /* The applet properties */
 extern Properties gtm_applet_prop;
 
-void gtm_open (void);
+gboolean gtm_open (void);
 
-gboolean gtm_add_url (gchar *url, gchar *dir, gboolean disable_proxy,
-                      gboolean disable_auto_dl);
+GTMAppletError gtm_add_url (gchar *url, gchar *dir, gboolean use_proxy,
+                            gboolean use_auto_dl);
 
 #endif /* _GTM_APPLET_H */
