@@ -35,9 +35,10 @@ dialog_about (void)
 {
     static GtkWidget *about = NULL;
     const gchar *authors[] = {
-	"Bruno Pires Marinho <bapm@rnl.ist.utl.pt>, Main author",
+	"Bruno Pires Marinho <bapm@netcabo.pt>, Main author",
 	"Gianluca Montecchi <gianluca@pluto.linux.it>",
 	"Ross Arnold <ronz@users.sourceforge.net>",
+        "Matthew Tuck  <matty@chariot.net.au>",
 	NULL
     };
 
