@@ -1,5 +1,6 @@
 /*
- *  Copyright (C) 1999, 2000 Bruno Pires Marinho
+ *  Copyright (C) 1999-2001 Bruno Pires Marinho
+ *  Copyright (C) 2000-2001 Matthew Tuck
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -26,16 +27,15 @@
 #include "file-list.h"
 #include "dialogs.h"
 #include "download-dirs.h"
+#include "dialog-common-elements.h"
 
 /* Structure that keeps the widgets with the information of the new download
  * file */
 typedef struct 
 {
-    GtkWidget *dlg;              /* GNOME dialog */
-    GtkWidget *url_list;         /* GtkCList */
-    GtkWidget *download_dir;     /* Entry */
-    GtkWidget *disable_proxy;    /* Toggle button */
-    GtkWidget *disable_auto_dl;  /* Check button */
+    GtkWidget       *dlg;      /* GNOME dialog */
+    GtkWidget       *url_list; /* GtkCList */
+    DlPolicyWidgets dl_policy;
 } NewDlData;
 
 #define ASC2HEXD(x) (((x) >= '0' && (x) <= '9') ? \
@@ -47,22 +47,12 @@ static void
 ok_add_files (GtkWidget *widget, NewDlData *new_dl_data)
 {
     FileData *file_data;
-    gchar *url, *dir, *error_msg;
-    gint length, pos;
-    gboolean disable_proxy, disable_auto_dl;
+    DlPolicyData dl_policy;
+    gchar *url, *error_msg;
+    gint pos;
 
-    /* Get download directory data */
-    dir = gtk_entry_get_text (GTK_ENTRY (new_dl_data->download_dir));
-
-    /* Get the disable proxy option data */
-    disable_proxy =
-        gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (
-            new_dl_data->disable_proxy));
-
-    /* Get the disable auto download option data */
-    disable_auto_dl = 
-        gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (
-	    new_dl_data->disable_auto_dl));
+    /* Get the download policy info from the widgets */
+    get_dl_policy_data (&dl_policy, &(new_dl_data->dl_policy));
 
     /* Add the URL from the url list to the file list */
     pos = 0;
@@ -71,8 +61,7 @@ ok_add_files (GtkWidget *widget, NewDlData *new_dl_data)
             gtk_clist_get_row_data (GTK_CLIST (new_dl_data->url_list),
                                     pos++)) != NULL) {
         /* Create the file data with the information */
-        file_data = file_data_create (url, dir, disable_proxy,
-                                      disable_auto_dl);
+        file_data = dl_policy_file_data_create (url, &dl_policy);
 
         /* Add the new download file to the file list (if not a duplicate) */
         if (file_list_add (GTK_CLIST (dl_file_list), file_data) == FALSE) {
@@ -90,19 +79,12 @@ ok_add_files (GtkWidget *widget, NewDlData *new_dl_data)
                                  NULL);
         error = gnome_message_box_new (error_msg, GNOME_MESSAGE_BOX_ERROR,
                                        GNOME_STOCK_BUTTON_OK, NULL);
+        /* FIXME?: Shouldn't this be parented? */
         gnome_dialog_run_and_close (GNOME_DIALOG (error));
     }
 
-    /* If dialog new or add changes default download dir update the def dl 
-     * dir */
-    if (gtm_pref.addnew_changes_def_dl_dir) {
-        g_free (gtm_pref.def_download_dir);
-        length = strlen (dir);
-        if (length != 0 && dir[length - 1] != '/')
-            gtm_pref.def_download_dir = g_strconcat (dir, "/", NULL);
-        else
-            gtm_pref.def_download_dir = g_strdup (dir);
-    }
+    /* If dialog changes default download dir update the def dl dir */
+    change_default_download_dir (dl_policy.download_dir);
 
     /* Destroy the dialog box and free unused that */
     gtk_widget_destroy (new_dl_data->dlg);
@@ -214,81 +196,64 @@ url_list_create (gchar *uri_list)
     return url_list;
 }
 
+/* Fill the contents of the dialog */
+static void
+dialog_add_contents (NewDlData *new_dl_data, gchar *uri_list)
+{
+    GtkWidget *label, *sw;
+    gchar *initial_download_dir, *dir;
+    /* URLs */
+    label = gtk_label_new (_ ("URLs to be added"));
+    gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (new_dl_data->dlg)->vbox), 
+                        label, FALSE, FALSE, 0);
+    new_dl_data->url_list = url_list_create (uri_list);
+    sw = gtk_scrolled_window_new (NULL, NULL);
+    gtk_container_add (GTK_CONTAINER (sw),
+                       GTK_WIDGET (new_dl_data->url_list));
+    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
+                                    GTK_POLICY_AUTOMATIC,
+                                    GTK_POLICY_AUTOMATIC);
+    gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (new_dl_data->dlg)->vbox), 
+                        sw, TRUE, TRUE, 0);
+
+    /* Download Policy */
+    /* FIXME: this assumes only zero or one URI in uri_list */
+    if (download_dirs_suggest_dir (uri_list, &dir))
+	initial_download_dir = dir;
+    else
+	initial_download_dir = gtm_pref.def_download_dir;
+    add_download_policy_widget (new_dl_data->dlg,
+                                &(new_dl_data->dl_policy),
+				initial_download_dir,
+				NULL, NULL);
+}
+
 
 /* Dialog used to add files to download */
 void
 dialog_add (gchar *uri_list)
 {
-    GtkWidget *label, *file_entry, *hbox1, *sw;
     NewDlData *new_dl_data;
-    gchar *dir;
 
     if (gtm_pref.confirm_dnd_url) {
         new_dl_data = g_new (NewDlData, 1);
 
         /* Create dialog box */
         new_dl_data->dlg = 
-            gnome_dialog_new (_ ("GTM - Add files to download"),
+            gnome_dialog_new (_ ("Add files to download"),
                               GNOME_STOCK_BUTTON_OK, GNOME_STOCK_BUTTON_CANCEL,
                               NULL);
         gnome_dialog_set_parent (GNOME_DIALOG (new_dl_data->dlg), 
                                  GTK_WINDOW (gtm_app));
 
-        /* Set its contents */
-        label = gtk_label_new (_ ("URLs to be added"));
-        gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (new_dl_data->dlg)->vbox), 
-                            label, FALSE, FALSE, 0);
-        new_dl_data->url_list = url_list_create (uri_list);
-        sw = gtk_scrolled_window_new (NULL, NULL);
-        gtk_container_add (GTK_CONTAINER (sw),
-                           GTK_WIDGET (new_dl_data->url_list));
-        gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
-                                        GTK_POLICY_AUTOMATIC,
-                                        GTK_POLICY_AUTOMATIC);
-        gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (new_dl_data->dlg)->vbox), 
-                            sw, TRUE, TRUE, 0);
+        /* Fill the contents */
+        dialog_add_contents (new_dl_data, uri_list);
 
-        label = gtk_label_new (_ ("Download dir:"));
-        gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (new_dl_data->dlg)->vbox), 
-                            label, FALSE, FALSE, 0);
-        file_entry = gnome_file_entry_new ("AddDownloadDir", 
-                                           _("GTM - Add Download Dir"));
-        new_dl_data->download_dir = 
-            gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (file_entry));
-        gnome_file_entry_set_directory (GNOME_FILE_ENTRY (file_entry), 1);
-        /* FIXME: this assumes only zero or one URI in uri_list */
-        if (download_dirs_suggest_dir (uri_list, &dir))
-            gtk_entry_set_text (GTK_ENTRY (new_dl_data->download_dir), dir);
-        else
-            gtk_entry_set_text (GTK_ENTRY (new_dl_data->download_dir),
-                                gtm_pref.def_download_dir);
-        gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (new_dl_data->dlg)->vbox),
-                            file_entry, FALSE, FALSE, 0);
-
-        hbox1 = gtk_hbox_new (FALSE, FALSE);
-        new_dl_data->disable_proxy = 
-            gtk_check_button_new_with_label (_ ("Disable proxy"));
-        gtk_box_pack_start (GTK_BOX (hbox1), new_dl_data->disable_proxy, 
-                            FALSE, FALSE, 0);
-        new_dl_data->disable_auto_dl =
-            gtk_check_button_new_with_label (_ ("Disable auto download"));
-        gtk_box_pack_start (GTK_BOX (hbox1), new_dl_data->disable_auto_dl,
-                            FALSE, FALSE, 0);
-        gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (new_dl_data->dlg)->vbox),
-                            hbox1, FALSE, FALSE, 0);
-
-        /* Configure the dialog box */
-        gnome_dialog_set_close (GNOME_DIALOG (new_dl_data->dlg), FALSE);
-        gnome_dialog_set_default (GNOME_DIALOG (new_dl_data->dlg), GNOME_OK);
-
-        /* Set the signal handlers */
-        gnome_dialog_button_connect (GNOME_DIALOG (new_dl_data->dlg), GNOME_OK,
-                                     GTK_SIGNAL_FUNC (ok_add_files),
-                                     (gpointer) new_dl_data);
-        gnome_dialog_button_connect (GNOME_DIALOG (new_dl_data->dlg),
-                                     GNOME_CANCEL,
-                                     GTK_SIGNAL_FUNC (cancel_add_files),
-                                     (gpointer) new_dl_data);
+        /* Set up OK/Cancel callbacks, defaults, etc */
+        configure_ok_cancel_dialog (GNOME_DIALOG (new_dl_data->dlg),
+                                    GTK_SIGNAL_FUNC (ok_add_files),
+                                    GTK_SIGNAL_FUNC (cancel_add_files),
+                                    (gpointer) new_dl_data);
 
         /* Show the dialog box and every thing it contains */
         gtk_widget_show_all (new_dl_data->dlg);
@@ -304,7 +269,7 @@ dialog_add (gchar *uri_list)
             /* Create the file data with the information */
             file_data = file_data_create (p_url->data,
                                           "",
-                                          FALSE, FALSE);
+                                          TRUE, TRUE);
 
             /* Add the new download file to the file list
              * (if not a duplicate) */
