@@ -536,7 +536,7 @@ create_download_page (PrefDialogData *pref)
     label = gtk_label_new (_ ("Default download dir:"));
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
     def_download_dir = gnome_file_entry_new ("DefDownloadDir", 
-                                             _("GTM - Def Download Dir"));
+                                             _("Def Download Dir"));
     pref->def_download_dir = gnome_file_entry_gtk_entry (
         GNOME_FILE_ENTRY (def_download_dir));
     gnome_file_entry_set_directory (GNOME_FILE_ENTRY (def_download_dir), 1);
@@ -850,7 +850,7 @@ dialog_prefs (void)
     pref_dialog_data = g_new (PrefDialogData, 1);
     pref_dialog_data->pbox = gnome_property_box_new ();
     gtk_window_set_title (GTK_WINDOW (pref_dialog_data->pbox),
-                          _ ("GTM - Preferences"));
+                          _ ("Preferences"));
     gnome_dialog_set_parent (GNOME_DIALOG (pref_dialog_data->pbox),
                              GTK_WINDOW (gtm_app));
     gtk_signal_connect (GTK_OBJECT (pref_dialog_data->pbox), "destroy",
