@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 1999, 2000 Bruno Pires Marinho
+ *  Copyright (C) 1999-2001 Bruno Pires Marinho
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -29,8 +29,8 @@ typedef struct
 {
     GtkWidget *pbox;                            /* GNOME Property Box */
     GtkWidget *url;                             /* Entry */
-    GtkWidget *disable_proxy;                   /* Toggle button */
-    GtkWidget *disable_auto_dl;                 /* Toggle button */
+    GtkWidget *use_proxy;                       /* Toggle button */
+    GtkWidget *use_auto_dl;                     /* Toggle button */
 } PropDialogData;
 
 
@@ -86,17 +86,17 @@ apply_prop (GtkWidget *widget, gint page_num, PropDialogData *prop)
                     g_free (url);
                 }
             }
-            file_data_set_disable_auto_dl (file_data,
-                                           gtk_toggle_button_get_active (
-                                               GTK_TOGGLE_BUTTON (
-                                                   prop->disable_auto_dl)));
+            file_data_set_use_auto_dl (file_data,
+                                       gtk_toggle_button_get_active (
+                                           GTK_TOGGLE_BUTTON (
+                                               prop->use_auto_dl)));
             break;
 
         case 1: /* Proxy */
-            file_data_set_disable_proxy (file_data,
-                                         gtk_toggle_button_get_active (
-                                             GTK_TOGGLE_BUTTON (
-                                                 prop->disable_proxy)));
+            file_data_set_use_proxy (file_data,
+                                     gtk_toggle_button_get_active (
+                                         GTK_TOGGLE_BUTTON (
+                                             prop->use_proxy)));
             break;            
     }
     download_info_update (file_data);
@@ -124,18 +124,18 @@ dialog_prop_update (PropDialogData *prop, FileData *file_data)
 {
     if (file_data != NULL) {
 	gtk_toggle_button_set_active 
-	    (GTK_TOGGLE_BUTTON (prop->disable_proxy),
-	     file_data->disable_proxy);
+	    (GTK_TOGGLE_BUTTON (prop->use_proxy),
+	     file_data->use_proxy);
         gtk_entry_set_text (GTK_ENTRY (prop->url), file_data->url);
         gtk_widget_set_sensitive (prop->url, TRUE);
 	gtk_toggle_button_set_active 
-	    (GTK_TOGGLE_BUTTON (prop->disable_auto_dl),
-	     file_data->disable_auto_dl);
-        gtk_widget_set_sensitive (prop->disable_auto_dl, TRUE);
+	    (GTK_TOGGLE_BUTTON (prop->use_auto_dl),
+	     file_data->use_auto_dl);
+        gtk_widget_set_sensitive (prop->use_auto_dl, TRUE);
     } else {
-	gtk_widget_set_sensitive (prop->disable_proxy, FALSE);
+	gtk_widget_set_sensitive (prop->use_proxy, FALSE);
 	gtk_widget_set_sensitive (prop->url, FALSE);
-	gtk_widget_set_sensitive (prop->disable_auto_dl, FALSE);
+	gtk_widget_set_sensitive (prop->use_auto_dl, FALSE);
     }
 
     /* If an update was made we need to disable the OK and APPLY buttons */
@@ -154,15 +154,15 @@ create_proxy_page (PropDialogData *prop)
     vbox = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
     gtk_container_set_border_width (GTK_CONTAINER (vbox), GNOME_PAD);
 
-    /* Disable proxy */
-    prop->disable_proxy = 
-	gtk_check_button_new_with_label (_ ("Disable proxy"));
-    gtk_box_pack_start (GTK_BOX (vbox), prop->disable_proxy, 
+    /* Use proxy */
+    prop->use_proxy = 
+	gtk_check_button_new_with_label (_ ("Use proxy"));
+    gtk_box_pack_start (GTK_BOX (vbox), prop->use_proxy, 
                         FALSE, FALSE, 0);
 
     /* Connect the signal that acknowledges the change on the widget to 
      * function that turns on the OK and APPLY buttons */
-    gtk_signal_connect (GTK_OBJECT (prop->disable_proxy), "toggled", 
+    gtk_signal_connect (GTK_OBJECT (prop->use_proxy), "toggled", 
 			GTK_SIGNAL_FUNC (prop_modified_cb), 
 			(gpointer) prop);
 
@@ -186,10 +186,10 @@ create_download_page (PropDialogData *prop)
     prop->url = gtk_entry_new ();
     gtk_box_pack_start (GTK_BOX (hbox), prop->url, TRUE, TRUE, 0);
 
-    /* Disable auto download */
-    prop->disable_auto_dl = 
-	gtk_check_button_new_with_label (_ ("Disable auto download"));
-    gtk_box_pack_start (GTK_BOX (vbox), prop->disable_auto_dl, 
+    /* Use auto download */
+    prop->use_auto_dl = 
+	gtk_check_button_new_with_label (_ ("Use auto download"));
+    gtk_box_pack_start (GTK_BOX (vbox), prop->use_auto_dl, 
                         FALSE, FALSE, 0);
 
     /* Connect the signal that acknowledges the change on the widget to 
@@ -197,7 +197,7 @@ create_download_page (PropDialogData *prop)
     gtk_signal_connect (GTK_OBJECT (prop->url), "changed", 
 			GTK_SIGNAL_FUNC (prop_modified_cb), 
 			(gpointer) prop);
-    gtk_signal_connect (GTK_OBJECT (prop->disable_auto_dl), "toggled", 
+    gtk_signal_connect (GTK_OBJECT (prop->use_auto_dl), "toggled", 
 			GTK_SIGNAL_FUNC (prop_modified_cb), 
 			(gpointer) prop);
 
@@ -232,7 +232,7 @@ dialog_prop (gboolean open_dialog, FileData *file_data)
     prop_dialog_data = g_new (PropDialogData, 1);
     prop_dialog_data->pbox = gnome_property_box_new ();
     gtk_window_set_title (GTK_WINDOW (prop_dialog_data->pbox), 
-			  _ ("GTM - Properties"));
+			  _ ("Properties"));
     gnome_dialog_set_parent (GNOME_DIALOG (prop_dialog_data->pbox), 
 			     GTK_WINDOW (gtm_app));
     gtk_signal_connect (GTK_OBJECT (prop_dialog_data->pbox), "destroy",
