@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 1999, 2000 Bruno Pires Marinho
+ *  Copyright (C) 1999-2001 Bruno Pires Marinho
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -180,28 +180,28 @@ int file_data_url_valid (const gchar *url)
             strncasecmp (url, "ftp://", 6) == 0 );
 }
 
-void file_data_set_disable_proxy (FileData *file_data,
-                                  gboolean disable_proxy)
+void file_data_set_use_proxy (FileData *file_data,
+                              gboolean use_proxy)
 {
     gchar *path;
 
-    file_data->disable_proxy = disable_proxy;
+    file_data->use_proxy = use_proxy;
     path = g_strdup_printf ("/gtm/File%d/disable_proxy",
                             file_data->id);
-    gnome_config_set_bool (path, file_data->disable_proxy);
+    gnome_config_set_bool (path, !file_data->use_proxy);
     gnome_config_sync ();
     g_free (path);
 }
 
-void file_data_set_disable_auto_dl (FileData *file_data,
-                                    gboolean disable_auto_dl)
+void file_data_set_use_auto_dl (FileData *file_data,
+                                gboolean use_auto_dl)
 {
     gchar *path;
 
-    file_data->disable_auto_dl = disable_auto_dl;
+    file_data->use_auto_dl = use_auto_dl;
     path = g_strdup_printf ("/gtm/File%d/disable_auto_Dl",
                             file_data->id);
-    gnome_config_set_bool (path, file_data->disable_auto_dl);
+    gnome_config_set_bool (path, !file_data->use_auto_dl);
     gnome_config_sync ();
     g_free (path);
 }
@@ -329,12 +329,13 @@ file_data_start_download (FileData *file_data)
             argv[5] = "-c";                   /* Continue download */
             argv[6] = "-t";                   /* Number of retries */
             argv[7] = g_strdup_printf ("%d", gtm_pref.num_retries);
-            argv[8] = "-T 30";                /* Wget timeout */
-            arg = 9;
+            argv[8] = "-T";                   /* Wget timeout */
+            argv[9] = "30";                   /* The value is hardwired! */
+            arg = 10;
 
             /* Proxy arguments */
             argv[arg++] = "-Y";
-            if (gtm_pref.use_proxy && !file_data->disable_proxy) {
+            if (gtm_pref.use_proxy && file_data->use_proxy) {
                 argv[arg++] = "on";
 
                 /* Proxy user and password */
@@ -399,6 +400,13 @@ file_data_start_download (FileData *file_data)
                              file_data);
         report_event ("start");
 
+        /* Scroll the list to make the file started visible */
+        if (file_data->file_list != NULL)
+            gtk_clist_moveto (GTK_CLIST (file_data->file_list),
+                              gtk_clist_find_row_from_data (
+                                  GTK_CLIST (file_data->file_list),
+                                  file_data), -1, 0.5, 0.0);
+
         /* Increase the number of downloads */
         num_of_download++;
     }
@@ -447,7 +455,7 @@ file_data_stop_download (FileData *file_data)
 
     /* Check if stop action disables auto download */
     if (gtm_pref.manual_stop_disables_auto_dl)
-        file_data->disable_auto_dl = TRUE;
+        file_data->use_auto_dl = FALSE;
 }
 
 void
@@ -465,8 +473,8 @@ file_data_restart_download (FileData *file_data)
 }
 
 FileData *
-file_data_create (gchar *url, gchar *dir, gboolean disable_proxy,
-                  gboolean disable_auto_dl)
+file_data_create (gchar *url, gchar *dir, gboolean use_proxy, 
+                  gboolean use_auto_dl)
 {
     FileData *file_data;
     gchar *filename, *prefix, *file_ids, *new_file_ids;
@@ -500,8 +508,8 @@ file_data_create (gchar *url, gchar *dir, gboolean disable_proxy,
     file_data->local_filename = g_strconcat (file_data->dir,
                                              file_data->filename,
                                              NULL);
-    file_data->disable_proxy = disable_proxy;
-    file_data->disable_auto_dl = disable_auto_dl;
+    file_data->use_proxy = use_proxy;
+    file_data->use_auto_dl = use_auto_dl;
     file_data->line = NULL;
     file_data->session_start_time = 0;
     file_data->session_start_size = 0;
@@ -524,9 +532,8 @@ file_data_create (gchar *url, gchar *dir, gboolean disable_proxy,
     gnome_config_push_prefix (prefix);
     gnome_config_set_string ("url", file_data->url);
     gnome_config_set_string ("dir", file_data->dir);
-    gnome_config_set_bool ("disable_proxy", file_data->disable_proxy);
-    gnome_config_set_bool ("disable_auto_dl",
-                               file_data->disable_auto_dl);
+    gnome_config_set_bool ("disable_proxy", !file_data->use_proxy);
+    gnome_config_set_bool ("disable_auto_dl", !file_data->use_auto_dl);
     gnome_config_pop_prefix ();
     gnome_config_sync ();
     g_free (prefix);
