@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 1999, 2000 Bruno Pires Marinho
+ *  Copyright (C) 1999-2001 Bruno Pires Marinho
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -38,8 +38,8 @@ typedef struct
     gchar *dir;                 /* Directory where the file will be saved */
     gchar *filename;            /* Name of the file being downloaded */
     gchar *local_filename;      /* Used to get the status of the download */
-    gboolean disable_proxy;     /* Used to disable the proxy use */
-    gboolean disable_auto_dl;   /* Used to disable the auto download */
+    gboolean use_proxy;         /* Used to use proxy */
+    gboolean use_auto_dl;       /* Used to use auto download */
     gchar *line;                /* Used to process the wget output */
     gint line_pos;              /* Used to process the wget output */
     guint32 total_size;         /* Total file size in bytes */
@@ -67,11 +67,9 @@ void file_data_set_url (FileData *file_data, gchar *url);
 
 int file_data_url_valid (const gchar *url);
 
-void file_data_set_disable_proxy (FileData *file_data,
-                                  gboolean disable_proxy);
+void file_data_set_use_proxy (FileData *file_data, gboolean use_proxy);
 
-void file_data_set_disable_auto_dl (FileData *file_data,
-                                    gboolean disable_auto_dl);
+void file_data_set_use_auto_dl (FileData *file_data, gboolean use_auto_dl);
 
 void file_data_update_statistics (FileData *file_data);
 
@@ -81,7 +79,7 @@ void file_data_stop_download (FileData *file_data);
 
 void file_data_restart_download (FileData *file_data);
 
-FileData * file_data_create (gchar *url, gchar *dir, gboolean disable_proxy,
-                             gboolean disable_auto_dl);
+FileData * file_data_create (gchar *url, gchar *dir, gboolean use_proxy,
+                             gboolean use_auto_dl);
 
 #endif /* _FILE_DATA_H */
