@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 1999, 2000 Bruno Pires Marinho
+ *  Copyright (C) 1999-2001 Bruno Pires Marinho
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -62,19 +62,20 @@ static FileListStats *list_stats = NULL;
 /* File list popup menu */
 static GnomeUIInfo menu_popup[] = {
 #define MENU_POPUP_REMOVE 0
-    GNOMEUIINFO_ITEM_STOCK (N_ ("Remove"), NULL, remove_cmd,
-			    GNOME_STOCK_PIXMAP_CLOSE),
+    GNOMEUIINFO_ITEM_STOCK (N_ ("Remove from list"), NULL, remove_cmd,
+			    GNOME_STOCK_MENU_CLOSE),
     GNOMEUIINFO_SEPARATOR,
 #define MENU_POPUP_START 2
     GNOMEUIINFO_ITEM_STOCK (N_ ("Start"), NULL, start_cmd,
-			    GNOME_STOCK_PIXMAP_EXEC),
+			    GNOME_STOCK_MENU_EXEC),
 #define MENU_POPUP_STOP 3
     GNOMEUIINFO_ITEM_STOCK (N_ ("Stop"), NULL, stop_cmd, 
-			    GNOME_STOCK_PIXMAP_STOP),
+			    GNOME_STOCK_MENU_STOP),
 #define MENU_POPUP_RESTART 4
     GNOMEUIINFO_ITEM_STOCK (N_ ("Restart"), NULL, restart_cmd, 
-			    GNOME_STOCK_PIXMAP_REFRESH),
+			    GNOME_STOCK_MENU_REFRESH),
     GNOMEUIINFO_SEPARATOR,
+#define MENU_POPUP_PROPERTIES 6
     GNOMEUIINFO_MENU_PROPERTIES_ITEM (properties_cmd, NULL),
     GNOMEUIINFO_END
 };
@@ -95,6 +96,8 @@ file_list_menu_popup_set_state (GtkCList *file_list)
             menu_popup[MENU_POPUP_STOP].widget, FALSE);
         gtk_widget_set_sensitive (
             menu_popup[MENU_POPUP_RESTART].widget, FALSE);
+        gtk_widget_set_sensitive (
+            menu_popup[MENU_POPUP_PROPERTIES].widget, FALSE);
     } else if (file_list->selection->next == NULL) {
         /* One file selected */
         gtk_widget_set_sensitive (
@@ -123,6 +126,8 @@ file_list_menu_popup_set_state (GtkCList *file_list)
         else
             gtk_widget_set_sensitive (
                 menu_popup[MENU_POPUP_RESTART].widget, FALSE);
+        gtk_widget_set_sensitive (
+            menu_popup[MENU_POPUP_PROPERTIES].widget, TRUE);
     } else {
         /* More than one file selected */
         gtk_widget_set_sensitive (
@@ -133,6 +138,8 @@ file_list_menu_popup_set_state (GtkCList *file_list)
             menu_popup[MENU_POPUP_STOP].widget, TRUE);
         gtk_widget_set_sensitive (
             menu_popup[MENU_POPUP_RESTART].widget, TRUE);
+        gtk_widget_set_sensitive (
+            menu_popup[MENU_POPUP_PROPERTIES].widget, FALSE);
     }
 }
 
@@ -177,6 +184,19 @@ file_list_event (GtkCList *file_list, GdkEvent *event, GtkMenu *popup)
     return FALSE;
 }
 
+static int
+file_list_key_press (GtkCList *file_list, GdkEventKey *event, gpointer data)
+{
+    if (GTK_CLIST (dl_file_list)->selection != NULL) {
+	if (event->keyval == GDK_Delete || event->keyval == GDK_KP_Delete) {
+	    dialog_remove();
+	    return TRUE;
+        }
+    }
+
+    return FALSE;
+}
+
 static void 
 file_list_select_row (GtkCList *file_list, gint row, gint column, 
 		      GdkEventButton *event, gpointer data)
@@ -362,6 +382,31 @@ file_list_drag_data_received (GtkWidget *widget, GdkDragContext *context,
     }
 }
 
+
+static void
+file_list_drag_data_get (GtkWidget *widget,
+                         GdkDragContext *context,
+                         GtkSelectionData *selection_data,
+                         guint info,
+                         guint time,
+                         gpointer file_list) 
+{
+    FileData *file_data;
+    GList *p;
+    
+    p = GTK_CLIST (file_list)->selection;
+    
+    if (p == NULL)
+        return;
+
+    file_data = (FileData *) gtk_clist_get_row_data
+        (GTK_CLIST (dl_file_list), (gint) p->data);
+
+    gtk_selection_data_set (selection_data,
+                            selection_data->target,
+                            8, file_data->url, strlen(file_data->url));
+}
+
 /* Function to create a file list */
 GtkWidget *
 file_list_create (void)
@@ -388,6 +433,13 @@ file_list_create (void)
         { "_NETSCAPE_URL", 0, TARGET_NETSCAPE_URL }
     };
 
+    static GtkTargetEntry source_table[] = {
+        { "gtk-clist-drag-reorder", 0, TARGET_CLIST },
+        { "text/plain", 0, TARGET_URL },
+        { "_NETSCAPE_URL", 0, TARGET_NETSCAPE_URL }
+        
+    };
+
     /* This panel data is used for drag auto-scroll */
     panel = g_new (Panel, 1);
 
@@ -429,6 +481,9 @@ file_list_create (void)
     gtk_signal_connect (GTK_OBJECT (file_list), "event",
                         GTK_SIGNAL_FUNC (file_list_event),
                         popup);
+    gtk_signal_connect (GTK_OBJECT (file_list), "key_press_event",
+                        GTK_SIGNAL_FUNC (file_list_key_press),
+                        NULL);
     gtk_signal_connect (GTK_OBJECT (file_list), "select_row", 
                         GTK_SIGNAL_FUNC (file_list_select_row),
                         NULL);
@@ -458,9 +513,15 @@ file_list_create (void)
 		       | GTK_DEST_DEFAULT_DROP,
                        target_table, 
 		       sizeof (target_table) / sizeof (target_table[0]),
-                       GDK_ACTION_COPY | GDK_ACTION_MOVE);
+                       GDK_ACTION_COPY | GDK_ACTION_MOVE);    
+    gtk_drag_source_set (file_list, GDK_BUTTON1_MASK, 
+                         source_table, 
+                         sizeof (source_table) / sizeof (source_table[0]), 
+                         GDK_ACTION_COPY);
     gtk_signal_connect (GTK_OBJECT (file_list), "drag_data_received",
                         GTK_SIGNAL_FUNC(file_list_drag_data_received), NULL);
+    gtk_signal_connect (GTK_OBJECT (file_list), "drag_data_get",
+                        GTK_SIGNAL_FUNC (file_list_drag_data_get), file_list);
 
     file_list_update_statistics (GTK_CLIST (file_list));
 
@@ -706,10 +767,10 @@ file_list_load_old_format_data (GtkCList *file_list, gint total_files)
         file_data->local_filename = g_strconcat (file_data->dir,
                                                  file_data->filename,
                                                  NULL);
-        file_data->disable_proxy = 
-            gnome_config_get_bool ("disable_proxy=FALSE");
-        file_data->disable_auto_dl = 
-            gnome_config_get_bool ("disable_auto_dl=FALSE");
+        file_data->use_proxy = 
+            !gnome_config_get_bool ("disable_proxy=FALSE");
+        file_data->use_auto_dl = 
+            !gnome_config_get_bool ("disable_auto_dl=FALSE");
         file_data->line = NULL;
         file_data->session_start_time = 0;
         file_data->session_start_size = 0;
@@ -741,9 +802,9 @@ file_list_load_old_format_data (GtkCList *file_list, gint total_files)
 	gnome_config_push_prefix (prefix);
 	gnome_config_set_string ("url", file_data->url);
 	gnome_config_set_string ("dir", file_data->dir);
-	gnome_config_set_bool ("disable_proxy", file_data->disable_proxy);
+	gnome_config_set_bool ("disable_proxy", !file_data->use_proxy);
 	gnome_config_set_bool ("disable_auto_dl",
-                               file_data->disable_auto_dl);
+                               !file_data->use_auto_dl);
 	gnome_config_set_int ("state", file_data->state);
 	gnome_config_set_int ("size", file_data->total_size);
 	gnome_config_set_int ("time", file_data->total_time);
@@ -828,10 +889,10 @@ file_list_load_data (GtkCList *file_list)
                             g_strconcat (file_data->dir,
                                          file_data->filename,
                                          NULL);
-                        file_data->disable_proxy = 
-                            gnome_config_get_bool ("disable_proxy=FALSE");
-                        file_data->disable_auto_dl = 
-                            gnome_config_get_bool ("disable_auto_dl=FALSE");
+                        file_data->use_proxy = 
+                            !gnome_config_get_bool ("disable_proxy=FALSE");
+                        file_data->use_auto_dl = 
+                            !gnome_config_get_bool ("disable_auto_dl=FALSE");
                         file_data->line = NULL;
                         file_data->session_start_time = 0;
                         file_data->session_start_size = 0;
@@ -886,7 +947,7 @@ file_list_start_auto_downloads (GtkCList *file_list)
     while (num_of_download < gtm_pref.num_of_auto_download
            && (file_data = 
                gtk_clist_get_row_data (GTK_CLIST (file_list), row)) != NULL) {
-        if (file_data->disable_auto_dl == FALSE)
+        if (file_data->use_auto_dl == TRUE)
             file_data_start_download (file_data);
         row++;
     }
@@ -901,11 +962,11 @@ file_list_stop_auto_downloads (GtkCList *file_list)
     row = 0;
     while ((file_data = gtk_clist_get_row_data 
             (GTK_CLIST(file_list), row)) != NULL ) {
-        if (file_data->disable_auto_dl == FALSE && 
+        if (file_data->use_auto_dl && 
             gtm_pref.stop_dl_on_link_loss) {
-            file_data_stop_download(file_data);
+            file_data_stop_download (file_data);
             /* This is set by file_data_stop_download */
-            file_data->disable_auto_dl = FALSE;
+            file_data->use_auto_dl = TRUE;
         }
         row++;
     }
