@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 1999, 2000 Bruno Pires Marinho
+ *  Copyright (C) 1999-2001 Bruno Pires Marinho
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -71,6 +71,12 @@ restart_cmd (GtkWidget *widget, gpointer data)
     dialog_restart ();
 }
 
+static void
+num_down_cmd (GtkWidget *widget, gpointer data)
+{
+    dialog_numdown ();
+}
+
 static void
 quit_cmd (GtkWidget *widget, gpointer data)
 {
@@ -170,11 +176,11 @@ toggle_auto_dl_cmd (GtkWidget *widget, gpointer data)
             (FileData *) gtk_clist_get_row_data (file_list, 
                                                  (gint) p->data);
         if (!GTK_IS_TOGGLE_BUTTON (widget))
-            file_data_set_disable_auto_dl (
+            file_data_set_use_auto_dl (
                 file_data,
                 GTK_CHECK_MENU_ITEM (widget)->active);
         else
-            file_data_set_disable_auto_dl (
+            file_data_set_use_auto_dl (
                 file_data,
                 GTK_TOGGLE_BUTTON (widget)->active);
         p = p->next;
@@ -199,14 +205,15 @@ static GnomeUIInfo main_menu_file[] = {
       new_cmd, NULL, NULL, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_NEW,
       'N', GDK_CONTROL_MASK, NULL },
 #define MAIN_MENU_FILE_REMOVE 2
-    { GNOME_APP_UI_ITEM, N_ ("_Remove..."), N_ ("Remove selected files"),
-      remove_cmd, NULL, NULL, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_CLOSE,
+    { GNOME_APP_UI_ITEM, N_ ("_Remove from list..."),
+      N_ ("Remove selected files from the list"),
+      remove_cmd, NULL, NULL, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_CLOSE,
       'D', GDK_CONTROL_MASK, NULL },
     GNOMEUIINFO_SEPARATOR,
     { GNOME_APP_UI_ITEM, N_ ("_List Statistics..."),
       N_ ("Show file list summary"),
       stats_cmd, NULL, NULL, GNOME_APP_PIXMAP_STOCK, 
-      GNOME_STOCK_PIXMAP_BOOK_YELLOW, 'L', GDK_CONTROL_MASK, NULL },
+      GNOME_STOCK_MENU_BOOK_YELLOW, 'L', GDK_CONTROL_MASK, NULL },
     GNOMEUIINFO_SEPARATOR,
     GNOMEUIINFO_MENU_EXIT_ITEM (quit_cmd, NULL),
     GNOMEUIINFO_END
@@ -233,16 +240,16 @@ static GnomeUIInfo main_menu_download[] = {
     GNOMEUIINFO_ITEM_STOCK (N_ ("Start"),
 			    N_ ("Start/Resume the download of the selected "
                                 "files"),
-                            start_cmd, GNOME_STOCK_PIXMAP_EXEC),
+                            start_cmd, GNOME_STOCK_MENU_EXEC),
 #define MAIN_MENU_DOWNLOAD_STOP 1
     GNOMEUIINFO_ITEM_STOCK (N_ ("Stop"),
                             N_ ("Stop the download of the selected files"),
-			    stop_cmd, GNOME_STOCK_PIXMAP_STOP),
+			    stop_cmd, GNOME_STOCK_MENU_STOP),
 #define MAIN_MENU_DOWNLOAD_RESTART 2
     GNOMEUIINFO_ITEM_STOCK (N_ ("Restart"),
 			    N_ ("Restart the download of selected files from "
                                 "the beginning"), restart_cmd, 
-			    GNOME_STOCK_PIXMAP_REFRESH),
+			    GNOME_STOCK_MENU_REFRESH),
     GNOMEUIINFO_END
 };
 
@@ -250,6 +257,14 @@ static GnomeUIInfo main_menu_settings[] = {
     GNOMEUIINFO_MENU_PREFERENCES_ITEM (preferences_cmd, NULL),
     GNOMEUIINFO_END
 };
+
+static GnomeUIInfo main_menu_tools[] = {
+    GNOMEUIINFO_ITEM_STOCK (N_ ("_Numeric Download"),
+                            N_ ("Download a group of URLs differing by "
+                                "number"),
+                            num_down_cmd, GNOME_STOCK_MENU_BOOK_OPEN ),
+    GNOMEUIINFO_END
+};
 	
 static GnomeUIInfo main_menu_help[] = {
     GNOMEUIINFO_HELP ("gtm"),
@@ -262,6 +277,7 @@ static GnomeUIInfo main_menu[] = {
     GNOMEUIINFO_MENU_FILE_TREE (main_menu_file),
     GNOMEUIINFO_MENU_EDIT_TREE (main_menu_edit),
     GNOMEUIINFO_SUBTREE (N_ ("_Download"), main_menu_download),
+    GNOMEUIINFO_SUBTREE (N_ ("_Tools"), main_menu_tools),
     GNOMEUIINFO_MENU_SETTINGS_TREE (main_menu_settings),
     GNOMEUIINFO_MENU_HELP_TREE (main_menu_help),
     GNOMEUIINFO_END
@@ -274,7 +290,8 @@ static GnomeUIInfo main_toolbar[] = {
 			    new_cmd, GNOME_STOCK_PIXMAP_NEW),
     GNOMEUIINFO_SEPARATOR,
 #define MAIN_TOOLBAR_REMOVE 2
-    GNOMEUIINFO_ITEM_STOCK (N_ ("Remove"), N_ ("Remove selected files"),
+    GNOMEUIINFO_ITEM_STOCK (N_ ("Remove"), 
+			    N_ ("Remove selected files from the list"),
 			    remove_cmd, GNOME_STOCK_PIXMAP_CLOSE),
     GNOMEUIINFO_SEPARATOR,
 #define MAIN_TOOLBAR_START 4
@@ -297,6 +314,7 @@ static GnomeUIInfo main_toolbar[] = {
                             N_ ("Toggle auto download of selected files"),
                             toggle_auto_dl_cmd, robot_xpm),
     GNOMEUIINFO_SEPARATOR,
+#define MAIN_TOOLBAR_PROPERTIES 10
     GNOMEUIINFO_ITEM_STOCK (N_ ("Properties"),
                             N_ ("Open properties for selected file"),
                             properties_cmd, GNOME_STOCK_PIXMAP_PROPERTIES),
@@ -336,6 +354,8 @@ menu_toolbar_set_state (GtkCList *file_list)
 	    main_menu_download[MAIN_MENU_DOWNLOAD_RESTART].widget, FALSE);
 	gtk_widget_set_sensitive (
 	    main_toolbar[MAIN_TOOLBAR_RESTART].widget, FALSE);
+        gtk_widget_set_sensitive (
+            main_toolbar[MAIN_TOOLBAR_PROPERTIES].widget, FALSE);
     } else if (file_list->selection->next == NULL) {
         /* One file selected */
         file_data = gtk_clist_get_row_data (file_list, 
@@ -348,6 +368,8 @@ menu_toolbar_set_state (GtkCList *file_list)
 	    main_menu_edit[MAIN_MENU_EDIT_TOGGLE_AUTO_DL].widget, TRUE);
 	gtk_widget_set_sensitive (
 	    main_toolbar[MAIN_TOOLBAR_TOGGLE_AUTO_DL].widget, TRUE);
+        gtk_widget_set_sensitive (
+            main_toolbar[MAIN_TOOLBAR_PROPERTIES].widget, TRUE );
         if (file_data->state == DL_NOT_STARTED 
             || file_data->state == DL_NOT_RUNNING) {
             gtk_widget_set_sensitive (
@@ -407,6 +429,8 @@ menu_toolbar_set_state (GtkCList *file_list)
 	    main_menu_download[MAIN_MENU_DOWNLOAD_RESTART].widget, TRUE);
 	gtk_widget_set_sensitive (
 	    main_toolbar[MAIN_TOOLBAR_RESTART].widget, TRUE);
+        gtk_widget_set_sensitive (
+            main_toolbar[MAIN_TOOLBAR_PROPERTIES].widget, FALSE);
     }
 }
 
@@ -417,9 +441,20 @@ void
 menu_toolbar_set_auto_dl (GtkCList *file_list)
 {
     FileData *file_data;
-    gboolean all_auto_dl_disabled;
+    gboolean all_use_auto_dl;
     GList *p;
 
+    /* Disable the callbacks to toggle_auto_dl_cmd so we don't
+     * homogenise the selection */
+    gtk_signal_handler_block_by_func (
+        GTK_OBJECT (main_menu_edit[MAIN_MENU_EDIT_TOGGLE_AUTO_DL].widget),
+        GTK_SIGNAL_FUNC (toggle_auto_dl_cmd),
+        file_list);
+    gtk_signal_handler_block_by_func (
+        GTK_OBJECT (main_toolbar[MAIN_TOOLBAR_TOGGLE_AUTO_DL].widget),
+        GTK_SIGNAL_FUNC (toggle_auto_dl_cmd),
+        file_list);
+
     if (file_list->selection == NULL) {
         /* No file selected */
     } else if (file_list->selection->next == NULL) {
@@ -429,20 +464,20 @@ menu_toolbar_set_auto_dl (GtkCList *file_list)
         gtk_check_menu_item_set_active (
             GTK_CHECK_MENU_ITEM (
                 main_menu_edit[MAIN_MENU_EDIT_TOGGLE_AUTO_DL].widget),
-            file_data->disable_auto_dl);
+            file_data->use_auto_dl);
         gtk_toggle_button_set_active (
             GTK_TOGGLE_BUTTON (
                 main_toolbar[MAIN_TOOLBAR_TOGGLE_AUTO_DL].widget),
-            file_data->disable_auto_dl);
+            file_data->use_auto_dl);
     } else {
         /* More than one file selected */
         p = file_list->selection;
-        all_auto_dl_disabled = TRUE;
+        all_use_auto_dl = TRUE;
         while (p != NULL) {
             file_data = (FileData *) gtk_clist_get_row_data (file_list, 
                                                              (gint) p->data);
-            if (file_data->disable_auto_dl == FALSE) {
-                all_auto_dl_disabled = FALSE;
+            if (file_data->use_auto_dl == FALSE) {
+                all_use_auto_dl = FALSE;
                 break;
             }
             p = p->next;
@@ -450,12 +485,22 @@ menu_toolbar_set_auto_dl (GtkCList *file_list)
         gtk_check_menu_item_set_active (
             GTK_CHECK_MENU_ITEM (
                 main_menu_edit[MAIN_MENU_EDIT_TOGGLE_AUTO_DL].widget),
-            all_auto_dl_disabled);
+            all_use_auto_dl);
         gtk_toggle_button_set_active (
             GTK_TOGGLE_BUTTON (
                 main_toolbar[MAIN_TOOLBAR_TOGGLE_AUTO_DL].widget),
-            all_auto_dl_disabled);
+            all_use_auto_dl);
     }
+
+    /* Reenable the disabled callbacks */
+    gtk_signal_handler_unblock_by_func (
+        GTK_OBJECT (main_menu_edit[MAIN_MENU_EDIT_TOGGLE_AUTO_DL].widget),
+        GTK_SIGNAL_FUNC (toggle_auto_dl_cmd),
+        file_list);
+    gtk_signal_handler_unblock_by_func (
+        GTK_OBJECT (main_toolbar[MAIN_TOOLBAR_TOGGLE_AUTO_DL].widget),
+        GTK_SIGNAL_FUNC (toggle_auto_dl_cmd),
+        file_list);
 }
 
 
