@@ -20,6 +20,7 @@
 #include <popt-gnome.h>
 #include <gnome.h>
 #include <libgnorba/gnorba.h>
+#include <libgnomeui/gnome-window-icon.h>
 #include <signal.h>
 #include <stdio.h>
 #include <unistd.h>
@@ -309,6 +310,7 @@ main (int argc, char *argv[])
     orb = gnome_CORBA_init_with_popt_table ("gtm", VERSION, &argc, argv,
                                             gtm_popt_options, 0, NULL, 
                                             GNORBA_INIT_SERVER_FUNC, &ev);
+    gnome_window_icon_set_default_from_file (GNOME_ICONDIR "/gtm.png");
     Exception (&ev);
 
     /* If we have a URL from the command line connect to the running gtm
@@ -334,6 +336,10 @@ main (int argc, char *argv[])
                 g_print (_ ("already in the list"));
                 g_print ("\n");
             }
+        } else {
+            /* GTM Server couldn't be started */
+            g_print (_ ("Couldn't start GTM"));
+            g_print ("\n");
         }
         
         return 0;
