@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 1999, 2000 Bruno Pires Marinho
+ *  Copyright (C) 1999-2001 Bruno Pires Marinho
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,10 +21,12 @@
 #include <string.h>
 #include <sys/stat.h>
 #include <unistd.h>
+#include <signal.h>
 #include "gtm.h"
 #include "file-data.h"
 #include "file-list.h"
 #include "wget-log.h"
+#include "download-info.h"
 
 /* Function to convert the wget notation of file size (55,449,600) */ 
 static guint32 
@@ -52,7 +54,8 @@ show_error (FileData *file_data, gchar *error_msg)
     /* Before showing the error message disable auto-download. If we don't do
      * this auto download retries to download the file again and with an error.
      */
-    file_data_set_disable_auto_dl (file_data, TRUE);
+    file_data_set_use_auto_dl (file_data, FALSE);
+    download_info_update(file_data);
     message = g_strconcat (error_msg, file_data->url, NULL);
     error = gnome_message_box_new (message, GNOME_MESSAGE_BOX_ERROR,
 				   GNOME_STOCK_BUTTON_OK, NULL);
@@ -62,7 +65,7 @@ show_error (FileData *file_data, gchar *error_msg)
 }
 
 
-static void
+static int
 wget_log_process_line (FileData *file_data)
 {
     gchar *p;
@@ -87,6 +90,9 @@ wget_log_process_line (FileData *file_data)
 	    else if (strncmp (file_data->line, "Connection to ", 14) == 0)
 		show_error (file_data,
                             _ ("Connection refused when downloading URL:\n"));
+	    else if (strstr (file_data->line, "No route to host") != NULL)
+		show_error (file_data,
+                            _ ("No route to host:\n"));
 	    else if (strncmp (file_data->line, "connect: ", 9) == 0)
 		show_error (file_data,
                             _ ("Connection refused when downloading URL:\n"));
@@ -96,6 +102,8 @@ wget_log_process_line (FileData *file_data)
 	    else
 		show_error (file_data,
                             _ ("Unknown error when downloading URL:\n"));
+	    kill (file_data->wget_pid, SIGKILL);
+	    return 1;
 	    break;
 
 	case DL_CONNECTED:
@@ -137,13 +145,14 @@ wget_log_process_line (FileData *file_data)
 	default:
 	    break;
     }
+    return 0;
 }
 
 void
 wget_log_process (FileData *file_data)
 {
     gchar buffer[MAX_WGET_LINE_SIZE * 2 + 1];
-    gint total_read, pos;
+    gint total_read, pos, res;
 
     do {
 	total_read = read (file_data->log_fd, buffer, MAX_WGET_LINE_SIZE * 2);
@@ -156,7 +165,9 @@ wget_log_process (FileData *file_data)
 		    pos++;
 	    } else {
 		file_data->line[file_data->line_pos] = '\0';
-		wget_log_process_line (file_data);
+		res = wget_log_process_line (file_data);
+		if (res == 1)
+                    break;
 		file_data->line_pos = 0;
 		pos++;
 	    }
